@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -227,7 +227,7 @@ class DashboardsServiceAsyncClient:
         Management <https://cloud.google.com/iam>`__.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
@@ -306,7 +306,7 @@ class DashboardsServiceAsyncClient:
         Management <https://cloud.google.com/iam>`__.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
@@ -388,7 +388,7 @@ class DashboardsServiceAsyncClient:
         Management <https://cloud.google.com/iam>`__.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
@@ -463,7 +463,7 @@ class DashboardsServiceAsyncClient:
         Management <https://cloud.google.com/iam>`__.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
@@ -526,7 +526,7 @@ class DashboardsServiceAsyncClient:
         Management <https://cloud.google.com/iam>`__.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
